@@ -216,7 +216,8 @@ gnome_font_face_get_prop (GObject *o, guint id, GValue *value, GParamSpec *pspec
 		g_value_set_string (value, face->entry->familyname);
 		break;
 	case PROP_WEIGHT:
-		g_value_set_string (value, face->entry->weight);
+		/* FIXME: we should be using the GnomeFontWeight Weight */
+		g_value_set_string (value, face->entry->speciesname);
 		break;
 	case PROP_ITALICANGLE:
 		/* FIXME: implement (Lauris) */
@@ -673,12 +674,42 @@ gnome_font_face_find_closest_from_pango_description (const PangoFontDescription
 
 	g_return_val_if_fail (desc != NULL, NULL);
 
-	weight = (pango_font_description_get_weight (desc) + 49)/ 100;
+	/* pango_font_description_get_weight returns a numerical enum */
+	/* value in the range from 100 to 900 with                    */
+	/* PANGO_WEIGHT_ULTRALIGHT = 200                              */
+	/* PANGO_WEIGHT_NORMAL     = 400                              */
+        /* PANGO_WEIGHT_HEAVY      = 900                              */
+
+	weight = pango_font_description_get_weight (desc);
 	style = pango_font_description_get_style (desc);
-	italic = ((style == PANGO_STYLE_OBLIQUE) || (style == PANGO_STYLE_ITALIC));
+	italic = ((style == PANGO_STYLE_OBLIQUE) 
+		  || (style == PANGO_STYLE_ITALIC));
 	family_name = pango_font_description_get_family (desc);
 
-	return gnome_font_face_find_closest_from_weight_slant (family_name, weight, italic);
+	/* gnome_font_face_find_closest_from_weight_slant requires as */
+	/* weight a GnomeFontWeight, a numerical value ranging from   */
+	/* 100 to 1100 with                                           */
+        /* 	GNOME_FONT_LIGHTEST = 100, */
+        /* 	GNOME_FONT_EXTRA_LIGHT = 100, */
+        /* 	GNOME_FONT_THIN = 200, */
+        /* 	GNOME_FONT_LIGHT = 300, */
+        /* 	GNOME_FONT_BOOK = 400, */
+        /* 	GNOME_FONT_REGULAR = 400, */
+        /* 	GNOME_FONT_MEDIUM = 500, */
+        /* 	GNOME_FONT_SEMI = 600, */
+        /* 	GNOME_FONT_DEMI = 600, */
+        /* 	GNOME_FONT_BOLD = 700, */
+        /* 	GNOME_FONT_HEAVY = 900, */
+        /* 	GNOME_FONT_EXTRABOLD = 900, */
+        /* 	GNOME_FONT_BLACK = 1000, */
+        /* 	GNOME_FONT_EXTRABLACK = 1100, */
+        /* 	GNOME_FONT_HEAVIEST = 1100 */
+
+	/* Since these values are reasonably close, we retain the same */
+        /* numerical values. */
+
+	return gnome_font_face_find_closest_from_weight_slant 
+		(family_name, weight, italic);
 }
 
 /* This returns GList of (guchar *) */
@@ -1672,7 +1703,7 @@ gnome_font_face_is_italic (GnomeFontFace * face)
 		e = face->entry;
 	}
 
-	return (e->italic_angle = 0.0 ? TRUE : FALSE);
+	return (e->italic_angle < 0 ? TRUE : FALSE);
 }
 
 gboolean
