@@ -74,7 +74,7 @@ typedef enum {
 	GNOME_META_GLYPHLIST,
 	GNOME_META_COLOR,
 	GNOME_META_LINE,
-	GNOME_META_DASH,
+	GNOME_META_DASH
 } GnomeMetaType;
 
 typedef enum {
