@@ -27,7 +27,8 @@
 #include <string.h>
 #include <ctype.h>
 
-#include <freetype/freetype.h>
+#include <ft2build.h>
+#include FT_FREETYPE_H
 #include <freetype/ftglyph.h>
 #include <freetype/ftbbox.h>
 #include <libart_lgpl/art_misc.h>
