@@ -31,7 +31,7 @@ G_END_DECLS
 
 #include <glib.h>
 
-GSList *gp_tt_split_file (const guchar *buf, guint len);
+GSList *gp_tt_split_file (const guchar *buf, guint len, guint face);
 
 G_END_DECLS
 
