@@ -47,6 +47,12 @@ struct _GPAPrinterClass {
 	GPANodeClass node_class;
 };
 
+typedef struct _GpaModuleInfo GpaModuleInfo;
+struct _GpaModuleInfo {
+	GPAList *  (*printer_list_append) 
+	(GPAList *printers, const gchar* path);
+};
+
 static void gpa_printer_class_init (GPAPrinterClass *klass);
 static void gpa_printer_init (GPAPrinter *printer);
 
@@ -99,6 +105,8 @@ gpa_printer_init (GPAPrinter *printer)
 	printer->name     = NULL;
 	printer->model    = NULL;
 	printer->settings = NULL;
+	printer->is_complete = FALSE;
+	printer->module_path = NULL;
 }
 
 static void
@@ -114,10 +122,46 @@ gpa_printer_finalize (GObject *object)
 	printer->name     = NULL;
 	printer->settings = NULL;
 	printer->model    = NULL;
+	printer->is_complete = FALSE;
+	my_g_free (printer->module_path);
+	printer->module_path = NULL;
+	
 
 	G_OBJECT_CLASS (parent_class)->finalize (object);
 }
 
+static void
+gpa_printer_load_data (GPAPrinter *printer)
+{
+	GpaModuleInfo info;
+	GModule *handle  = NULL;
+	gboolean (*init) (GpaModuleInfo *info);
+	void (*load_data) (GPAPrinter *printer);
+
+	if (printer->is_complete)
+		return;
+
+	g_return_if_fail (printer->module_path != NULL);
+
+	if ((handle = g_module_open (printer->module_path, 
+				      G_MODULE_BIND_LAZY)) &&
+	     g_module_symbol (handle, "gpa_module_init", 
+			      (gpointer*) &init) &&
+	     g_module_symbol (handle, "gpa_module_load_data", 
+			      (gpointer*) &load_data)) {
+		if (init (&info))
+			load_data (printer);
+	} else
+		g_warning ("gpa_module_load_data cannot be retrieved from "
+			   "module %s", printer->module_path);
+
+	if (handle)
+		g_module_close (handle);
+
+	return;
+}
+
+
 static gboolean
 gpa_printer_verify (GPANode *node)
 {
@@ -126,6 +170,10 @@ gpa_printer_verify (GPANode *node)
 	printer = GPA_PRINTER (node);
 
 	gpa_return_false_if_fail (printer->name);
+
+	if (!printer->is_complete)
+		return TRUE;
+
 	gpa_return_false_if_fail (printer->settings);
 	gpa_return_false_if_fail (gpa_node_verify (printer->settings));
 	gpa_return_false_if_fail (printer->model);
@@ -282,11 +330,6 @@ gpa_printer_new_from_file (const gchar *file)
 	return printer;
 }
 
-typedef struct _GpaModuleInfo GpaModuleInfo;
-struct _GpaModuleInfo {
-	GPAList *  (*printer_list_append) (GPAList *printers);
-};
-
 /**
  * gpa_printer_list_load_from_module:
  * @path: 
@@ -304,7 +347,7 @@ gpa_printer_list_load_from_module (GPAList *printers, const gchar *path)
 	handle = g_module_open (path, G_MODULE_BIND_LAZY);
 	if (!handle) {
 		g_warning ("Can't g_module_open %s\n", path);
-		goto module_error;
+	        return retval;
 	}
 
 	if (!g_module_symbol (handle, "gpa_module_init", (gpointer*) &init)) {
@@ -317,7 +360,7 @@ gpa_printer_list_load_from_module (GPAList *printers, const gchar *path)
 		goto module_error;
 	}
 
-	(info.printer_list_append) (printers);
+	(info.printer_list_append) (printers, path);
 	retval = TRUE;
 	
 module_error:
@@ -530,16 +573,93 @@ gpa_printer_get_by_id (const guchar *id)
 GPANode *
 gpa_printer_get_default_settings (GPAPrinter *printer)
 {
-	GPANode *child;
+	GPANode *child = NULL;
 	
 	g_return_val_if_fail (printer != NULL, NULL);
 	g_return_val_if_fail (GPA_IS_PRINTER (printer), NULL);
 
-	child = gpa_list_get_default (GPA_LIST (printer->settings));
+	gpa_printer_load_data (printer);
+
+	if (printer->is_complete)
+		child = gpa_list_get_default (GPA_LIST (printer->settings));
 
 	return child;
 }
 
+/**
+ * gpa_printer_new_stub:
+ * @id: 
+ * @name: 
+ *
+ * Create a new printer node and set it up
+ * 
+ * Return Value: the newly created printer, NULL on error
+ **/
+GPANode *
+gpa_printer_new_stub (const gchar *id, const gchar *name, 
+		      const gchar *path)
+{
+	GPAPrinter *printer;
+	GPANode *check;
+
+	g_return_val_if_fail (id && id[0], NULL);
+	g_return_val_if_fail (name && name[0], NULL);
+	g_return_val_if_fail (gpa_initialized (), NULL);
+
+	check = gpa_printer_get_by_id (id);
+	if (check) {
+		g_warning ("Can't create printer \"%s\" because the id \"%s\" is already used", name, id);
+		gpa_node_unref (check);
+		return NULL;
+	}
+
+
+	printer = (GPAPrinter *) gpa_node_new (GPA_TYPE_PRINTER, id);
+	printer->name     = g_strdup (name);
+
+	printer->module_path = g_strdup (path);
+	printer->is_complete = FALSE;
+
+	return (GPANode *) printer;	
+}
+
+gboolean  
+gpa_printer_complete_stub (GPAPrinter *printer, 
+			   GPAModel *model, GPASettings *settings)
+{
+	GPAList *list;
+
+	g_return_val_if_fail (printer->is_complete != TRUE, FALSE);
+	g_return_val_if_fail (model != NULL, FALSE);
+	g_return_val_if_fail (GPA_IS_MODEL (model), FALSE);
+	g_return_val_if_fail (settings != NULL, FALSE);
+	g_return_val_if_fail (GPA_IS_SETTINGS (settings), FALSE);
+	g_return_val_if_fail (gpa_initialized (), FALSE);
+
+	list = gpa_list_new (GPA_TYPE_SETTINGS, "Settings", TRUE);
+	
+	printer->model    = gpa_node_attach (GPA_NODE (printer),
+					     GPA_NODE (gpa_reference_new (GPA_NODE (model), "Model")));
+	printer->settings = gpa_node_attach (GPA_NODE (printer),
+					     GPA_NODE (list));
+	printer->is_complete = TRUE;
+
+	gpa_node_reverse_children (GPA_NODE (printer));
+
+	gpa_list_prepend     (list, GPA_NODE (settings));
+	gpa_list_set_default (list, GPA_NODE (settings));
+
+	settings->printer = gpa_reference_new (GPA_NODE (printer), "Printer");
+	/* We sink the model reference because we have a GPAReference to it
+	 * we take ownership of the settings, so we don't unref them
+	 */
+	gpa_node_unref (GPA_NODE (model));
+
+	return TRUE;
+}
+
+
+
 /**
  * gpa_printer_new:
  * @id: 
@@ -583,6 +703,7 @@ gpa_printer_new (const gchar *id, const gchar *name, GPAModel *model, GPASetting
 					     GPA_NODE (gpa_reference_new (GPA_NODE (model), "Model")));
 	printer->settings = gpa_node_attach (GPA_NODE (printer),
 					     GPA_NODE (list));
+	printer->is_complete = TRUE;
 
 	gpa_node_reverse_children (GPA_NODE (printer));
 
@@ -615,6 +736,8 @@ gpa_printer_get_settings_by_id (GPAPrinter *printer, const guchar *id)
 	g_return_val_if_fail (GPA_IS_PRINTER (printer), NULL);
 	g_return_val_if_fail (id && id[0], NULL);
 
+	gpa_printer_load_data (printer);
+
 	g_assert (printer->settings);
 	child = printer->settings->children;
 	while (child) {
