@@ -144,7 +144,7 @@ gp_transport_file_open (GnomePrintTransport *transport)
 
 	g_return_val_if_fail (tf->name != NULL, GNOME_PRINT_ERROR_UNKNOWN);
 
-	tf->fd = open (tf->name, O_CREAT | O_TRUNC | O_WRONLY, S_IRUSR | S_IWUSR | S_IRGRP | S_IWGRP);
+	tf->fd = open (tf->name, O_CREAT | O_TRUNC | O_WRONLY, S_IRUSR | S_IWUSR | S_IRGRP | S_IWGRP | S_IROTH | S_IWOTH);
 
 	if (tf->fd < 0) {
 		g_warning ("Opening file %s for output failed", tf->name);
