@@ -36,7 +36,7 @@ typedef enum {
 	BACKEND_PS,
 	BACKEND_PDF,
 	BACKEND_META,
-	BACKEND_UNKNOWN,
+	BACKEND_UNKNOWN
 } BackendType;
 
 static gchar *sequence_str = NULL;
